@@ -17,92 +17,92 @@
 #   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
 
-#'Fetch Internet Data
+#' Fetch Internet Data
 #'
-#'Get investment data from the internet.
+#' Get investment data from the internet.
 #'
-#'\code{getYahooData} fetches individual stock data from the Yahoo! Finance
-#'website.  It also adjusts price for splits and dividends, and volume for
-#'splits.  See the Warning section, and note that it is deprecated in favor
-#'of getSymbols in the quantmod package.
+#' \code{getYahooData} fetches individual stock data from the Yahoo! Finance
+#' website.  It also adjusts price for splits and dividends, and volume for
+#' splits.  See the Warning section, and note that it is deprecated in favor
+#' of getSymbols in the quantmod package.
 #'
-#'\code{stockSymbols} fetches instrument symbols from the nasdaq.com website,
-#'and adjusts the symbols to be compatible with the Yahoo! Finance website.
+#' \code{stockSymbols} fetches instrument symbols from the nasdaq.com website,
+#' and adjusts the symbols to be compatible with the Yahoo! Finance website.
 #'
-#'@aliases WebData getYahooData stockSymbols
-#'@param symbol Yahoo! Finance instrument symbol.
-#'@param start Numeric; first date of desired data, in YYYYMMDD format.
-#'Default is first date of series.
-#'@param end Numeric; last date of desired data, in YYYYMMDD format.  Default
-#'is last date of series.
-#'@param freq Desired data frequency.  One of \code{"daily"}, \code{"weekly"},
-#'\code{"monthly"}.
-#'@param type Type of data to return.  One of \code{"price"}, or
-#'\code{"split"}.  \code{type="split"} will return both split and dividend
-#'data.
-#'@param adjust Logical; if \code{TRUE}, the Open, High, Low, and Close prices
-#'will be adjusted for dividends and splits, and Volume will be adjusted for
-#'dividends.
-#'@param quiet Logical; if \code{TRUE}, status messages will be printed to the
-#'console.
-#'@param exchange Character vector of exchange names on which desired
-#'instrument symbols are traded.
-#'@param sort.by Character vector of columns by which returned data will be
-#'sorted.  Must be one or more of \code{"Name"}, \code{"Symbol"},
-#'\code{"Market.Cap"}, or \code{"Exchange"}.
-#'@return \code{getYahooData} returns an xts object containing the columns:
+#' @aliases WebData getYahooData stockSymbols
+#' @param symbol Yahoo! Finance instrument symbol.
+#' @param start Numeric; first date of desired data, in YYYYMMDD format.
+#' Default is first date of series.
+#' @param end Numeric; last date of desired data, in YYYYMMDD format.  Default
+#' is last date of series.
+#' @param freq Desired data frequency.  One of \code{"daily"}, \code{"weekly"},
+#' \code{"monthly"}.
+#' @param type Type of data to return.  One of \code{"price"}, or
+#' \code{"split"}.  \code{type="split"} will return both split and dividend
+#' data.
+#' @param adjust Logical; if \code{TRUE}, the Open, High, Low, and Close prices
+#' will be adjusted for dividends and splits, and Volume will be adjusted for
+#' dividends.
+#' @param quiet Logical; if \code{TRUE}, status messages will be printed to the
+#' console.
+#' @param exchange Character vector of exchange names on which desired
+#' instrument symbols are traded.
+#' @param sort.by Character vector of columns by which returned data will be
+#' sorted.  Must be one or more of \code{"Name"}, \code{"Symbol"},
+#' \code{"Market.Cap"}, or \code{"Exchange"}.
+#' @return \code{getYahooData} returns an xts object containing the columns:
 #'
-#'\code{stockSymbols} returns a character vector containing all the listed
-#'symbols for the given exchanges.
-#' \describe{
-#'    \item{ Date }{ Trade date, in CCYYMMDD format. }
-#'    \item{ Open }{ Open price. }
-#'    \item{ High }{ High price. }
-#'    \item{ Low }{ Low price. }
-#'    \item{ Close }{ Close price. }
-#'    \item{ Volume }{ Volume. }
-#' }
-#'@note The symbols returned by \code{stockSymbols} may not be in the format
-#'necessary to retrieve data using \code{getYahooData}.
+#' \code{stockSymbols} returns a character vector containing all the listed
+#' symbols for the given exchanges.
+#'  \describe{
+#'     \item{ Date }{ Trade date, in CCYYMMDD format. }
+#'     \item{ Open }{ Open price. }
+#'     \item{ High }{ High price. }
+#'     \item{ Low }{ Low price. }
+#'     \item{ Close }{ Close price. }
+#'     \item{ Volume }{ Volume. }
+#'  }
+#' @note The symbols returned by \code{stockSymbols} may not be in the format
+#' necessary to retrieve data using \code{getYahooData}.
 #'
-#'\code{getYahooData} has only been tested on daily data.  It isn't known if
-#'the function correctly adjusts data for any other frequency.
-#'@author Joshua Ulrich
-#'@keywords ts
-#'@examples
+#' \code{getYahooData} has only been tested on daily data.  It isn't known if
+#' the function correctly adjusts data for any other frequency.
+#' @author Joshua Ulrich
+#' @keywords ts
+#' @examples
 #'
-#' ### Note: you must have a working internet
-#' ### connection for these examples to work!
-#' if (interactive()) {
-#'   ge <- getYahooData("GE", 19990404, 20050607, adjust = FALSE)
+#'  ### Note: you must have a working internet
+#'  ### connection for these examples to work!
+#'  if (interactive()) {
+#'    ge <- getYahooData("GE", 19990404, 20050607, adjust = FALSE)
 #'
-#'   nyse.symbols <- stockSymbols("NYSE")
-#' }
-#'
-#'@section Warning:
-#'As of TTR 0.23-2, \code{getYahooData} has been patched to work with changes
-#'to Yahoo Finance, which also included the following changes to the raw data:
-#'  \itemize{
-#'    \item The adjusted close column appears to no longer include dividend adjustments
-#'    \item The open, high, and low columns are adjusted for splits, and
-#'    \item The raw data may contain missing values.
-#'    \item The raw data may contain errors.
+#'    nyse.symbols <- stockSymbols("NYSE")
 #'  }
 #'
-#'As of TTR 0.24.2, \code{stockSymbols} began using data from NASDAQ's FTP
-#'site because the data from the original site is no longer available. This
-#'new file does not contain data for the columns: LastSale, MarketCap,
-#'IPOyear, Sector, and Industry. All the columns still appear in the results,#'but all the values in the columns are set to \code{NA}.
+#' @section Warning:
+#' As of TTR 0.23-2, \code{getYahooData} has been patched to work with changes
+#' to Yahoo Finance, which also included the following changes to the raw data:
+#'   \itemize{
+#'     \item The adjusted close column appears to no longer include dividend adjustments
+#'     \item The open, high, and low columns are adjusted for splits, and
+#'     \item The raw data may contain missing values.
+#'     \item The raw data may contain errors.
+#'   }
 #'
-#'@references
+#' As of TTR 0.24.2, \code{stockSymbols} began using data from NASDAQ's FTP
+#' site because the data from the original site is no longer available. This
+#' new file does not contain data for the columns: LastSale, MarketCap,
+#' IPOyear, Sector, and Industry. All the columns still appear in the results,#' but all the values in the columns are set to \code{NA}.
 #'
-#' \itemize{
-#'   \item \href{https://quant.stackexchange.com/questions/1640/where-to-download-list-of-all-common-stocks-traded-on-nyse-nasdaq-and-amex/1862}{Quant StackExchange: Download list of all stock symbols?}
-#'   \item \href{https://www.nasdaqtrader.com/trader.aspx?id=CQSsymbolconvention}{CQS symbol convention}
-#'   \item \href{https://web.archive.org/web/20111023221931/http://help.yahoo.com/l/us/yahoo/finance/quotes/quote-02.html}{Yahoo Finance symbol conventions}
-#' }
+#' @references
 #'
-#'@rdname WebData
+#'  \itemize{
+#'    \item \href{https://quant.stackexchange.com/questions/1640/where-to-download-list-of-all-common-stocks-traded-on-nyse-nasdaq-and-amex/1862}{Quant StackExchange: Download list of all stock symbols?}
+#'    \item \href{https://www.nasdaqtrader.com/trader.aspx?id=CQSsymbolconvention}{CQS symbol convention}
+#'    \item \href{https://web.archive.org/web/20111023221931/http://help.yahoo.com/l/us/yahoo/finance/quotes/quote-02.html}{Yahoo Finance symbol conventions}
+#'  }
+#'
+#' @rdname WebData
 "stockSymbols" <-
 function(exchange = c("AMEX", "NASDAQ", "NYSE", "ARCA", "BATS", "IEX"),
          sort.by = c("Exchange", "Symbol"),
@@ -114,7 +114,7 @@ function(exchange = c("AMEX", "NASDAQ", "NYSE", "ARCA", "BATS", "IEX"),
   # See "NYSE "behind the dot" or Nasdaq 5th-letter codes and other special
   # codes" here:
   # http://en.wikipedia.org/wiki/Ticker_symbol
-  # 
+  #
   # AMEX / NYSE Mappings (NASDAQ doesn't need transformation?):
   # Exchanges -> Yahoo
   # /WS       -> -WT
@@ -135,32 +135,32 @@ function(exchange = c("AMEX", "NASDAQ", "NYSE", "ARCA", "BATS", "IEX"),
   exchange <- match.arg(exchange, several.ok=TRUE)
   sort.by  <- match.arg(sort.by, symbols.colnames, several.ok=TRUE)
 
-  # nasdaqlisted.txt
-  nasdaq.colnames <-
-    c("Symbol",
-      "Security.Name",
-      "Market.Category",
-      "Test.Issue",
-      "Financial.Status",
-      "Round.Lot.Size",
-      "ETF",
-      "NextShares")
+  ### nasdaqlisted.txt
+  ##nasdaq.colnames <-
+  ##  c("Symbol",
+  ##    "Security.Name",
+  ##    "Market.Category",
+  ##    "Test.Issue",
+  ##    "Financial.Status",
+  ##    "Round.Lot.Size",
+  ##    "ETF",
+  ##    "NextShares")
 
   .market.category <-
     c(Q = "NASDAQ Global Select MarketSM",
       G = "NASDAQ Global MarketSM",
       S = "NASDAQ Capital Market")
 
-  # otherlisted.txt
-  other.colnames <-
-    c("ACT.Symbol",
-      "Security.Name",
-      "Exchange",
-      "CQS.Symbol",
-      "ETF",
-      "Round.Lot.Size",
-      "Test.Issue",
-      "NASDAQ.Symbol")
+  ### otherlisted.txt
+  ##other.colnames <-
+  ##  c("ACT.Symbol",
+  ##    "Security.Name",
+  ##    "Exchange",
+  ##    "CQS.Symbol",
+  ##    "ETF",
+  ##    "Round.Lot.Size",
+  ##    "Test.Issue",
+  ##    "NASDAQ.Symbol")
 
   .exchange <-
     c(A = "AMEX",
@@ -192,7 +192,8 @@ function(exchange = c("AMEX", "NASDAQ", "NYSE", "ARCA", "BATS", "IEX"),
       flush.console()
     }
     curl::curl_download(nasdaq.url, destfile = tmp)
-    nasdaq <- read.table(tmp, header = TRUE, sep = "|", quote = "", fill = TRUE)
+    nasdaq <- read.table(tmp, header = TRUE, sep = "|", quote = "",
+                         fill = TRUE, na.strings = NULL)
 
     # add symbols columns not in file
     nasdaq$Name <- nasdaq$Security.Name
@@ -217,7 +218,8 @@ function(exchange = c("AMEX", "NASDAQ", "NYSE", "ARCA", "BATS", "IEX"),
     }
 
     curl::curl_download(other.url, destfile = tmp)
-    other <- read.table(tmp, header = TRUE, sep = "|", quote = "", fill = TRUE)
+    other <- read.table(tmp, header = TRUE, sep = "|", quote = "",
+                        fill = TRUE, na.strings = NULL)
 
     # remove last row (File creation time)
     other <- other[-nrow(other),]
@@ -260,13 +262,13 @@ function(exchange = c("AMEX", "NASDAQ", "NYSE", "ARCA", "BATS", "IEX"),
 
   # Pretty rownames
   rownames(symbols) <- NULL
-  
+
   return(symbols)
 }
 
 #-------------------------------------------------------------------------#
 
-#'@rdname WebData
+#' @rdname WebData
 "getYahooData" <-
 function(symbol, start, end, freq="daily", type="price", adjust=TRUE, quiet=FALSE) {
 
@@ -351,10 +353,10 @@ function(symbol, start, end, freq="daily", type="price", adjust=TRUE, quiet=FALS
         divspl <- getYahooData(symbol, start, freq="daily", type="split",
                     adjust=FALSE, quiet=TRUE)
         ohlc   <- merge(ohlc, divspl, all=TRUE)
-        
+
         # If there are no div/spl, then ohlc is a zero-width xts object
         if(NROW(divspl) != 0) {
-          
+
           adj <- adjRatios(ohlc[,'Split'],ohlc[,'Div'],ohlc[,'Close'])
           s.ratio <- adj[,1]
           d.ratio <- adj[,2]
